@@ -1,4 +1,8 @@
+"""
+This module contains the base ReservoirStorage.
+"""
 from abc import ABC
+
 from .base import BaseStorage
 
 
@@ -15,5 +19,6 @@ class ReservoirStorage(BaseStorage, ABC):
             size: int,
             store_targets: bool = False
     ):
+        super().__init__()
         self.size = size
         self.store_targets = store_targets
